pub struct ResolvedAction {
pub label: String,
pub bytes_decoded: Vec<u8>,
pub group: Option<String>,
pub description: Option<String>,
}Expand description
One Action after byte-escape decoding and CLI-override merging.
bytes_decoded is the raw byte sequence written to guest stdin when
the button is clicked; the original TOML bytes string is not kept.
Fields
label: Stringbytes_decoded: Vec<u8>group: Option<String>description: Option<String>Trait Implementations
Sourceimpl Clone for ResolvedAction
impl Clone for ResolvedAction
Sourcefn clone(&self) -> ResolvedAction
fn clone(&self) -> ResolvedAction
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResolvedAction
impl Debug for ResolvedAction
Sourceimpl PartialEq for ResolvedAction
impl PartialEq for ResolvedAction
Sourcefn eq(&self, other: &ResolvedAction) -> bool
fn eq(&self, other: &ResolvedAction) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for ResolvedAction
impl StructuralPartialEq for ResolvedAction